package de.mlessmann.certassist.models;

import lombok.Builder;
import lombok.Data;

@Data
@Builder
public class CertificateInfo {

    private RequestType type;
    private String trustingAuthority;

    @Builder.Default
    private int requestedKeyLength = 4096;

    @Builder.Default
    private int requestedValidityDays = 365;

    private CertificateInfoSubject subject;
    private CertificateInfoSubject issuer;
    private CertificateInfoExtension extension;

    public enum RequestType {
        ROOT_AUTHORITY,
        STANDALONE_CERTIFICATE,
        NORMAL_CERTIFICATE,
    }

    public static class CertificateInfoBuilder {

        public CertificateInfoBuilder subject(CertificateInfoSubject.CertificateInfoSubjectBuilder builder) {
            this.subject = builder.build();
            return this;
        }

        public CertificateInfoBuilder issuer(CertificateInfoSubject.CertificateInfoSubjectBuilder builder) {
            this.issuer = builder.build();
            return this;
        }

        public CertificateInfoBuilder extension(CertificateInfoExtension.CertificateInfoExtensionBuilder builder) {
            this.extension = builder.build();
            return this;
        }
    }
}
