package de.mlessmann.certassist.openssl;

import de.mlessmann.certassist.models.CertificateInfoExtension;
import de.mlessmann.certassist.models.CertificateInfoSubject;
import java.time.OffsetDateTime;
import java.util.Collections;
import java.util.List;
import java.util.Objects;
import lombok.Builder;
import org.springframework.lang.Nullable;

@Builder
public record X509CertificateInfo(
    CertificateInfoSubject subject,
    @Nullable CertificateInfoSubject issuer,
    String serial,
    OffsetDateTime notBefore,
    OffsetDateTime notAfter,
    List<CertificateInfoExtension> extensions
) {
    public X509CertificateInfo {
        Objects.requireNonNull(subject);
        Objects.requireNonNull(serial);
        Objects.requireNonNull(notBefore);
        Objects.requireNonNull(notAfter);
    }

    @Override
    public List<CertificateInfoExtension> extensions() {
        if (extensions == null) {
            return Collections.emptyList();
        }
        return Collections.unmodifiableList(extensions);
    }

    public boolean hasExtensions() {
        return extensions != null && !extensions.isEmpty();
    }
}
